import { ApiOption } from './ApiOption';
/**
 * Options specifying the expected data within the {@link ApiResponse}.
 *
 * @author Onur Gürsoy
 */
export declare class ApiOptions {
    /**
     * List of enabled options for a single criterion.
     */
    enabledOptions: ApiOption[];
    /**
     * Constructs a new {@link ApiOptions} object where only the specified options are enabled.
     *
     * @param enabledOptions - List of {@link ApiOption} to enable.
     */
    constructor(enabledOptions?: ApiOption[]);
    /**
     * Checks whether or not the specified option is enabled.
     *
     * @param option - {@link ApiOption} to check.
     * @return {@code true} if the option is enabled and {@code false} otherwise.
     */
    readonly isEnabled: (option: ApiOption) => boolean;
    /**
     * Checks whether or not the specified option is <strong>not</strong> enabled.
     *
     * @param option - {@link ApiOption} to check.
     * @return {@code true} if the option is not enabled and {@code false} otherwise.
     */
    readonly isDisabled: (option: ApiOption) => boolean;
    /**
     * Enables the specified option.
     *
     * @param option - {@link ApiOption} to enable.
     */
    readonly enable: (option: ApiOption) => boolean;
    /**
     * Disables the specified option.
     *
     * @param option - {@link ApiOption} to disable.
     * @return {@code true} if the option's state changed from enabled to disabled or {@code false} if it was already disabled.
     */
    readonly disable: (option: ApiOption) => boolean;
    /**
     * Sets the state of the given option to enabled or disabled depending on the given boolean.
     *
     * @param option  - {@link ApiOption} to set the state of.
     * @param enabled - New state of the option. {@code true} enables the option and {@code false} disables it.
     * @return {@code true} if the option changed its state to the new state and {@code false} if the option was already in the specified state (enabled/disabled).
     */
    readonly set: (option: ApiOption, enabled: boolean) => boolean;
    /**
     * Enables all available options. Calling this method is equivalent to calling the {@link #enable(ApiOption)} method for all available {@link ApiOption}.
     */
    readonly enableAll: () => void;
    /**
     * Disables all available options. Calling this method is equivalent to calling the {@link #disable(ApiOption)} method for all available {@link ApiOption}.
     */
    readonly disableAll: () => void;
}
