import { ApiOption } from './ApiOption';
import { ApiOptions } from './ApiOptions';
import { Criterion } from './Criterion';
import { DataFormat } from './DataFormat';
/**
 * Analysis request for the Juracus API.
 *
 * @author Onur Gürsoy
 */
export declare class ApiRequest {
    /**
     * {@link DataFormat} of the provided file data.
     */
    readonly dataFormat: DataFormat;
    /**
     * BASE64 Encoded binary data of the file to analyze.
     */
    readonly encodedData: string;
    /**
     * Unique identifier for the API user. This identifier ensures the response can be send to the correct API user.
     */
    readonly connectionId: string;
    /**
     * Object containing the tasks as entries of criteria and their options for the analysis.
     */
    readonly tasks: {
        [p: string]: ApiOptions;
    };
    private constructor();
    private validateData;
    /**
     * Constructs a new {@link ApiRequest} requesting an analysis of the specified {@link Criterion} with their corresponding {@link ApiOptions}.
     * <p>
     * <strong>WARNING:</strong>
     * The given {@link ApiOptions} are deeply copied. Changing them after calling this Constructor will not change the constructed object itself. To change options after constructing the {@link ApiRequest} use the provided
     * {@link #enableOption(Criterion, ApiOption)}, {@link #disableOption(Criterion, ApiOption)} and {@link #setOption(Criterion, ApiOption, boolean)} methods.
     * </p>
     *
     * @param tasks        - {@link Map} containing the criteria to analyze together with their {@link ApiOptions}.
     * @param dataFormat   - Format of the provided file data.
     * @param encodedData  - Data of the file to analyze. You can find the supported file types here: {@link DataFormat}.
     * @param connectionId - Unique identifier for the API user to respond to.
     *
     *
     */
    static readonly createFromFullSpecification: (tasks: Map<Criterion, ApiOptions>, dataFormat: DataFormat, encodedData: string, connectionId: string) => ApiRequest;
    /**
     * Constructs a new {@link ApiRequest} requesting an analysis of all specified criteria.
     *
     * @param criteria     - {@link Array} of criteria to analyze.
     * @param dataFormat   - Format of the provided file data.
     * @param encodedData  - Data of the file to analyze. You can find the supported file types here: {@link DataFormat}.
     * @param connectionId - Unique identifier of the API user to respond to.
     */
    static readonly createFromCriteria: (criteria: readonly Criterion[], dataFormat: DataFormat, encodedData: string, connectionId: string) => ApiRequest;
    /**
     * Constructs a new {@link ApiRequest} requesting an analysis of all specified criteria with the given options.
     * <p>
     * <strong>WARNING:</strong>
     * The given {@link ApiOptions} are deeply copied. Changing them after calling this Constructor will not change the constructed object itself. To change options after constructing the {@link ApiRequest} use the provided
     * {@link #enableOption(Criterion, ApiOption)}, {@link #disableOption(Criterion, ApiOption)} and {@link #setOption(Criterion, ApiOption, boolean)} methods.
     * </p>
     *
     * @param criteria       - {@link Array} of criteria to analyze.
     * @param defaultOptions - {@link ApiOptions} default options to use for each analyzed criterion.
     * @param dataFormat     - Format of the provided file data.
     * @param encodedData    - Data of the file to analyze. You can find the supported file types here: {@link DataFormat}.
     * @param connectionId   - Unique identifier of the API user to respond to.
     */
    static readonly createFromCriteriaWithOptions: (criteria: readonly Criterion[], defaultOptions: ApiOptions, dataFormat: DataFormat, encodedData: string, connectionId: string) => ApiRequest;
    /**
     * Adds an analysis task to this request.
     *
     * @param criterion - {@link Criterion} to request an analysis for.
     * @param options   - {@link ApiOptions} for the specified criterion.
     * @throws Error if the specified criterion is already in this request. If you would like to change the options use the {@link #enableOption(Criterion, ApiOption)}, {@link #disableOption(Criterion, ApiOption)} and
     *                                  {@link #setOption(Criterion, ApiOption, boolean)} methods.
     */
    readonly addTask: (criterion: Criterion, options: ApiOptions) => void;
    /**
     * Enables the specified option for the given criterion.
     *
     * @param criterion - {@link Criterion} to enable the given option for.
     * @param option    - {@link ApiOption} to enable.
     * @return {@code true} if this method changed the underlying {@link ApiOptions} for the specified criterion and {@code false} otherwise.
     */
    readonly enableOption: (criterion: Criterion, option: ApiOption) => boolean;
    /**
     * Disables the specified option for the given criterion.
     *
     * @param criterion - {@link Criterion} to disable the given option for.
     * @param option    - {@link ApiOption} to disable.
     * @return {@code true} if this method changed the underlying {@link ApiOptions} for the specified criterion and {@code false} otherwise.
     */
    readonly disableOption: (criterion: Criterion, option: ApiOption) => boolean;
    /**
     * Enables or disables the given option for the specified criteria depending on the boolean parameter.
     *
     * @param criterion - {@link Criterion} to enable or disable the option for.
     * @param option    - {@link ApiOption} to enable or disable.
     * @param enabled   - {@code true} if the option should be enabled and {@code false} otherwise.
     * @return {@code true} if this method changed the underlying {@link ApiOptions} for the specified criterion and {@code false} otherwise.
     */
    readonly setOption: (criterion: Criterion, option: ApiOption, enabled: boolean) => boolean;
    /**
     * Returns a copy of the analysis options chosen for the specified criterion.
     *
     * @param criterion - {@link Criterion} to get the options of.
     * @return {@link ApiOptions} for the specified {@link Criterion}.
     * @throws Error if the specified criterion is not requested for analysis.
     */
    readonly getApiOptions: (criterion: Criterion) => ApiOptions;
}
