import { AnalysisResults } from './AnalysisResults';
import { ApiCriterionMetadataKey } from './ApiCriterionMetadataKey';
import { ApiDocumentMetadataKey } from './ApiDocumentMetadataKey';
import { ApiError } from './ApiError';
import { ApiMetadata } from './ApiMetadata';
import { Clause } from './Clause';
import { Criterion } from './Criterion';
import { MetaDataObjectType } from './MetaDataObjectType';
/**
 * <ul>
 *   <li>documentText - The analyzed text in the (during the request) uploaded file.</li>
 *   <li>results      - Object from the UUID of a criterion to the analysis result. Defaults to an empty Object.</li>
 *   <li>errors       - {@link Array} of errors which occurred during the process. This parameter defaults to an empty {@link Array}.</li>
 * </ul>
 *
 */
export declare type ApiResponseObject = {
    documentText: string;
    results: {
        [p: string]: AnalysisResults;
    };
    errors: readonly ApiError[];
    documentMetadata: {
        [p: string]: ApiMetadata<MetaDataObjectType>;
    };
};
/**
 * Response of the Juracus API to an {@link ApiRequest}.
 *
 * @author Onur Gürsoy
 */
export declare class ApiResponse {
    readonly documentText: string;
    readonly results: {
        [p: string]: AnalysisResults;
    };
    readonly errors: readonly ApiError[];
    readonly documentMetadata: {
        [p: number]: ApiMetadata<MetaDataObjectType>;
    };
    /**
     * Constructs a new {@link ApiResponse} object as answer to an {@link ApiRequest}.
     *
     * @param responseParameters containing data to construct ApiResponse
     */
    constructor(responseParameters: ApiResponseObject);
    /**
     * Returns the analysis results for the specified criterion.
     *
     * @param criterion - {@link Criterion} to get the analysis results for.
     * @return {@link AnalysisResults} object containing the results.
     */
    readonly getResult: (criterion: Criterion) => AnalysisResults;
    /**
     * Returns the texts found by the Juracus AI which are classified as relevant to the given criterion.
     *
     * @param criterion - {@link Criterion} to get the as relevant classified text passages for.
     * @return {@link List} of all as relevant for the given criterion specified text passages.
     * <p>
     * <strong>IMPORTANT</strong>
     * The returned list can still be empty if the Juracus AI did not find any relevant texts for the specified criterion.
     * </p>
     * @throws Error if the Juracus AI was not able to analyze the specified criterion.
     *                                <p>
     *                                <strong>IMPORTANT</strong>
     *                                the returned list may still be empty if no exception is thrown if the Juracus AI did not find any relevant text for the criterion but tried to analyze it.
     *                                </p>
     */
    readonly getClauses: (criterion: Criterion) => Clause[];
    /**
     * Returns metadata which is not directly connected to analyzed criteria but to the whole document based on the provided {@link ApiDocumentMetadataKey}.
     * @param key which identifies what kind of data is requested.
     * @return {@link ApiMetadata} object.
     */
    readonly getDocumentMetadata: (key: ApiDocumentMetadataKey) => any;
    readonly getCriterionMetadata: (criterion: Criterion, key: ApiCriterionMetadataKey) => ApiMetadata<MetaDataObjectType>;
    /**
     * Checks whether or not errors occurred during the API call.
     * @return {@code true} if errors occurred and {@code false} otherwise.
     */
    readonly hasErrors: () => boolean;
}
