/**
 * Class representation of Dates where not all information might be given (e.g. "march 2022", which is lacking information about the concrete day of the month).
 *
 * @author Onur Gürsoy
 */
export declare class SparseDate {
    private readonly day;
    private readonly month;
    private readonly year;
    private static readonly MAX_DAY;
    private static readonly MAX_MONTH;
    private static readonly MIN_YEAR;
    private static readonly MAX_YEAR;
    private static readonly DAY;
    private static readonly MONTH;
    private static readonly YEAR;
    private static readonly SURELY_YEAR;
    private static readonly STR_MONTH;
    private static readonly STRMONTH_PATTERNS;
    private static readonly PATTERNS;
    /**
     * @param day   optional day of the month from 1 - 31 or 0 if unknown
     * @param month required month from 1 to 12
     * @param year  optional year
     * @throws IllegalArgumentException if day < 0 or > 31, if month < 0 or > 12, if year < 1899 (besides 0) or year > 2199
     */
    constructor(day: number, month: number, year: number);
    /**
     * Parses a {@link SparseDate} from the given {@link String}.
     *
     * @param date - Text to parse the {@link SparseDate} from.
     * @return {@link SparseDate} representation of the given {@link String} or {@code null} if no date can be parsed.
     * @throws IOException if any I/O error occurs.
     */
    static parseDate: (date: string) => SparseDate;
    /**
     * Checks if this {@link SparseDate} contains a specified day.
     *
     * @return {@code true} if the day of the month is specified and {@code false} otherwise.
     */
    readonly hasDay: () => boolean;
    /**
     * Checks if this {@link SparseDate} contains a specified month.
     *
     * @return {@code true} if the month is specified and {@code false} otherwise.
     */
    readonly hasMonth: () => boolean;
    /**
     * Checks if this {@link SparseDate} contains a specified year.
     *
     * @return {@code true} if the year is specified and {@code false} otherwise.
     */
    readonly hasYear: () => boolean;
    /**
     * Returns the day of the month without preceding zero.
     *
     * @return day of the month without preceding zero as {@link String}.
     * @throws IllegalStateException if the day is unknown.
     */
    readonly getD: () => string;
    /**
     * Returns the day of the month with preceding zero.
     *
     * @return day of the month with preceding zero as {@link String}.
     * @throws IllegalStateException if the day is unknown.
     */
    readonly getDD: () => string;
    /**
     * Returns the month without preceding zero.
     *
     * @return the month without preceding zero as {@link String}.
     * @throws IllegalStateException if the month is unknown.
     */
    readonly getM: () => string;
    /**
     * Returns the month with preceding zero.
     *
     * @return the month with preceding zero as {@link String}.
     * @throws IllegalStateException if the month is unknown.
     */
    readonly getMM: () => string;
    /**
     * Returns the month in written German (1 = Januar, 2 = Februar, ..., 12 = Dezember)
     *
     * @return the month in written German as {@link String}.
     * @throws IllegalStateException if the month is unknown.
     */
    readonly getMMM: () => string;
    /**
     * Returns the year in the two digit format.
     *
     * @return two digit version of the year as {@link String}.
     * @throws IllegalStateException if the year is unknown.
     */
    readonly getYY: () => string;
    /**
     * Returns the year in four digit version.
     *
     * @return four digit version of {@link String}.
     */
    readonly getYYYY: () => string;
    private static parse;
    private static parseYear;
    private static parseDay;
    private static parseMonth;
    private static parseMonthName;
    private static readonly hasGroup;
}
